@@ -2,7 +2,7 @@
 
 // fixg2sxd - a utility to convert fig to sxd format
 
-// Copyright (C) 2003-2008 Alexander Bürger, acfb@users.sourceforge.net
+// Copyright (C) 2003-2010 Alexander Bürger, acfb@users.sourceforge.net
 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -161,7 +161,7 @@ static void write_file( ostream& sxdfile )
     ZipWriter sxd( sxdfile );
 
     // write mimetype
-    sxd.GetStream("mimetype") << "application/vnd.sun.xml.draw"  << endl;
+    sxd.GetStream("mimetype") << "application/vnd.sun.xml.draw" << flush;
 
     { // write manifest
         Node manifest("manifest:manifest");
@@ -208,7 +208,7 @@ static void write_file( ostream& sxdfile )
 
     { // write content.xml
         ostream& contentxml = sxd.GetStream( "content.xml" );
-        contentxml << xmlheader
+        contentxml << xmlheader << endl
                    << "<!DOCTYPE office:document-content PUBLIC"
             " \"-//OpenOffice.org//DTD OfficeDocument 1.0//EN\""
             " \"office.dtd\">" << endl
@@ -408,17 +408,20 @@ static void read_file( istream& figfile )
 static void usage( const char* cmdname, bool err=true )
 {
     ostream& out = (err ? cerr : cout);
-    out << cmdname << " [-w] [-l(ine)w(idth)1 l] figfile [sxdfile]" << endl << endl
+    out << cmdname << " [-w] [-l(ine)w(idth)1 l] [-stylebase s] figfile [sxdfile]" << endl << endl
         << "Using `-' as figfile makes the program read from stdin." << endl
         << endl
         << "Omitting sxdfile when figfile ends with .fig or .xfig, makes"<<endl
         << "the sxd file be named like figfile with .(x)fig replaced by .sxd."
         << endl << endl
-        << "With -linewidth1 or -lw1 the with of lines with thickness 1 in xfig" <<endl
+        << "With -linewidth1 or -lw1 the with of lines with thickness 1 in xfig" << endl
         << "can be set (in cm), e.g. to 0 to have fine lines." << endl << endl
-        << "With -w files with out-of-specification values will be accepted," <<endl
+        << "With -w files with out-of-specification values will be accepted," << endl
         << "but a warning will be printed and the bad values sanitized." << endl << endl
-        << "This is fig2sxd version 0.20. (C) 2003-2008 Alexander Bürger."
+        << "With -stylebase the \"Fig2Sxd\" prefix for styles can be replaced" << endl
+        << "which can be useful if several converted figures are joined in" << endl
+        << "the same document." << endl << endl
+        << "This is fig2sxd version 0.21. (C) 2003-2010 Alexander Bürger."
         << endl;
 }
 
@@ -471,6 +474,14 @@ int try_catched_main( int argc, char* argv[] )
             fail( "linewith must be >= 0" );
         LineFillStyle::linewith1 = w;
     }
+    if( option( "-stylebase", tmp, argc, argv ) ) {
+        ostringstream lbase;
+        lbase << tmp << "Line";
+        LineFillStyle::base = lbase.str();
+        ostringstream tbase;
+        tbase << tmp << "Text";
+        TextStyle::base = tbase.str();
+    }
     if( option0( "-w", argc, argv ) ) {
         out_of_range_error = false;
         cerr << "Out of range values will be sanitized." << endl;
