@@ -2,7 +2,7 @@
 
 // fixg2sxd - a utility to convert fig to sxd format
 
-// Copyright (C) 2003-2008 Alexander Bürger, acfb@users.sourceforge.net
+// Copyright (C) 2003-2010 Alexander Bürger, acfb@users.sourceforge.net
 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -109,7 +109,7 @@ namespace {
     }
 }
 
-const char* LineFillStyle::base = "Fig2SxdLine";
+string LineFillStyle::base = "Fig2SxdLine";
 
 int LineFillStyle::number = 10;
 
