@@ -2,7 +2,7 @@
 
 // fixg2sxd - a utility to convert fig to sxd format
 
-// Copyright (C) 2003-2008 Alexander Bürger, acfb@users.sourceforge.net
+// Copyright (C) 2003-2010 Alexander Bürger, acfb@users.sourceforge.net
 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -27,7 +27,7 @@
 
 tsset textstyles;
 
-const char* TextStyle::base = "Fig2SxdText";
+string TextStyle::base = "Fig2SxdText";
 int TextStyle::number = 10;
 
 string TextStyle::stylenumber() const
